==> helldivers-2-api-0.0.1.tar.gz: helldivers-2-api-0.0.1/README.md <==
<div align="center">
<h1>
  <br>
  <a href="https://git.jdrodenkirchen.de/drodenkirchen/helldivers-2-python-api/"><img src="https://git.jdrodenkirchen.de/drodenkirchen/helldivers-2-python-api/-/raw/main/static/logo.png" alt="HD2API" width="200"></a>
  <br>
  Helldivers 2 Python API
  <br>
</h1>

<h4 align="center">A Python abstraction layer for the [unofficial Helldivers 2 API](https://helldiverstrainingmanual.com/api)</h4>

<p>
  <a href="http://www.wtfpl.net/">
    <img src="https://img.shields.io/badge/licence-WTFPL-green?style=flat" alt="WTFPL">
  </a>
  <a href=https://www.python.org/downloads/""><img src="https://img.shields.io/badge/Python-3.11%20%7C%203.12-blue?style=flat"></a>
  <a href="https://git.jdrodenkirchen.de/drodenkirchen/helldivers-2-python-api/">
    <img src="https://img.shields.io/badge/version-0.0.1-orange?style=flat">
  </a>
</p>

<p>
  <a href="#key-features">Key Features</a> •
  <a href="#how-to-use">How To Use</a> •
  <a href="#credits">Credits</a> •
  <a href="#license">License</a>
</p>

</div>

## Key Features

* Fully typed data model
  - Planets
  - Sectors
  - Factions
  - Events
  - Campaigns
  - Attacks
* Simple to use
  - Use your IDE's autocompletion to simply traverse the data model tree
* Easy Install
  - Only dependency is [requests](https://pypi.org/project/requests/)!

## How To Use

Simply install [the PyPI package via pip]().

Checkout the examples in the subdirectory `examples` for a primer on how to use this package.

## Credits

This software uses the following open source packages:

- [Python](https://www.python.org/)
- [requests](https://pypi.org/project/requests/)

## License

```
        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
                Version 2, December 2004

Copyright (C) 2024 David Rodenkirchen <davidr.develop@gmail.com>

Everyone is permitted to copy and distribute verbatim or modified
copies of this license document, and changing it is allowed as long
as the name is changed.

        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

0. You just DO WHAT THE FUCK YOU WANT TO.
```


---

> [jdrodenkirchen.de](https://jdrodenkirchen.de/) &nbsp;&middot;&nbsp;
> Git: [@drodenkirchen](https://git.jdrodenkirchen.de/drodenkirchen) &nbsp;&middot;&nbsp;
> Steam: [Typhus](https://steamcommunity.com/id/originaltyphus/)

==> helldivers-2-api-0.0.2.tar.gz: helldivers-2-api-0.0.2/README.md <==
<div align="center">
<h1>
  <a href="https://git.jdrodenkirchen.de/drodenkirchen/helldivers-2-python-api/"><img src="https://git.jdrodenkirchen.de/drodenkirchen/helldivers-2-python-api/-/raw/main/static/logo.png" alt="HD2API" width="200"></a>
  <br>
  Helldivers 2 Python API
  <br>
</h1>

<h4 align="center">A Python abstraction layer for the [unofficial Helldivers 2 API](https://helldiverstrainingmanual.com/api)</h4>

<p>
  <a href="http://www.wtfpl.net/">
    <img src="https://img.shields.io/badge/licence-WTFPL-green?style=flat" alt="WTFPL">
  </a>
  <a href="https://www.python.org/downloads/"><img src="https://img.shields.io/badge/Python-3.11%20%7C%203.12-blue?style=flat"></a>
  <a href="https://pypi.org/project/helldivers-2-api/">
    <img src="https://img.shields.io/badge/version-0.0.2-orange?style=flat">
  </a>
</p>

</div>

## Key Features

* Fully typed data model
  - Planets
  - Sectors
  - Factions
  - GlobalEvents and PlanetEvents
  - Campaigns
  - Attacks
  - News Feed
  - Joint Operations
* Simple to use
  - Use your IDE's autocompletion to simply traverse the data model tree
* Easy Install
  - Only dependency is [requests](https://pypi.org/project/requests/)!

## How To Use

Simply install [the PyPI package via pip](https://pypi.org/project/helldivers-2-api/).

Checkout the examples in the subdirectory `examples` for a primer on how to use this package.

## Credits

This software uses the following open source packages:

- [Python](https://www.python.org/)
- [requests](https://pypi.org/project/requests/)

## License

```
        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
                Version 2, December 2004

Copyright (C) 2024 David Rodenkirchen <davidr.develop@gmail.com>

Everyone is permitted to copy and distribute verbatim or modified
copies of this license document, and changing it is allowed as long
as the name is changed.

        DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

0. You just DO WHAT THE FUCK YOU WANT TO.
```


---

> [jdrodenkirchen.de](https://jdrodenkirchen.de/) &nbsp;&middot;&nbsp;
> Git: [@drodenkirchen](https://git.jdrodenkirchen.de/drodenkirchen) &nbsp;&middot;&nbsp;
> Steam: [Typhus](https://steamcommunity.com/id/originaltyphus/)
